@@ -46,8 +46,8 @@ typedef struct
     gulong display_keys;
     gulong pressed_front_keys;
     gulong pressed_display_keys;
-    guchar key_codes[512]; 
-    guchar sensor_codes[32];
+    gchar key_codes[512]; 
+    gchar sensor_codes[32];
     guchar last_error;
 } ALVADeviceData;
 
@@ -386,7 +386,7 @@ alva_brl_input_parser (gint new_val)
 }
 
 gint 
-alva_brl_send_dots (guchar *dots, gshort count, gshort blocking)
+alva_brl_send_dots (guchar *dots, gchar* text, gshort cursor_position, gshort count, gshort blocking)
 {
 
     gint rv = 0, realcnt;
@@ -441,7 +441,7 @@ alva_brl_send_dots (guchar *dots, gshort count, gshort blocking)
 		
     sendbuff[realcnt++] = 0x0D;
 	
-    rv = brl_ser_send_data (sendbuff, realcnt, blocking);
+    rv = brl_ser_send_data ((gchar*)sendbuff, realcnt, blocking);
 	
     return rv;	
 }
