@@ -154,91 +154,91 @@ struct poptOption poptopt[] =
 	 &gn_defaultmode, 	
 	 0, 
 	 "Launch in execution with default settings", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-braille",	
 	 'b', 	
 	 POPT_ARG_NONE, 
 	 &gn_braille_enable,		
 	 0, 
 	 "enable braille service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-braille",	
 	 'B', 	
 	 POPT_ARG_NONE, 
 	 &gn_braille_disable,		
 	 0, 
 	 "enable braille service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-speech",	
 	 's', 	
 	 POPT_ARG_NONE, 
 	 &gn_speech_enable,		
 	 0, 
 	 "enable speech service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-speech",	
 	 'S', 	
 	 POPT_ARG_NONE, 
 	 &gn_speech_disable,		
 	 0, 
 	 "disable speech service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "enable-magnifier",	
 	 'm', 	
 	 POPT_ARG_NONE, 
 	 &gn_magnifier_enable,		
 	 0, 
 	 "enable magnifier service",  
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-magnifier",	
 	 'M', 	
 	 POPT_ARG_NONE, 
 	 &gn_magnifier_disable,		
 	 0, 
 	 "disable magnifier service",  
-	 NULL
-	},
+ 	 NULL
+ 	},
 
-	{
+ 	{
 	 "enable-braille-monitor", 
 	 'o', 
 	 POPT_ARG_NONE, 
 	 &gn_braille_monitor_enable, 	
 	 0, 
 	 "enable braille monitor service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "disable-braille-monitor", 
 	 'O', 
 	 POPT_ARG_NONE, 
 	 &gn_braille_monitor_disable, 	
 	 0, 
 	 "disable braille monitor service", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "login", 
 	 'l', 
 	 POPT_ARG_NONE, 
 	 &gn_login, 	
 	 0, 
 	 "Used at login time", 
-	 NULL
-	},
-	{
+ 	 NULL
+ 	},
+ 	{
 	 "braille-port", 
 	 'p',   
 	 POPT_ARG_INT,  
@@ -246,8 +246,8 @@ struct poptOption poptopt[] =
 	 0, 
 	 "Serial port (ttyS)", 
 	 "ttyS[1..4]"
-	},
-	{
+ 	},
+ 	{
 	 "braille-device", 
 	 'e', 
 	 POPT_ARG_STRING, 
@@ -255,17 +255,17 @@ struct poptOption poptopt[] =
 	 0, 
 	 "Braille Device", 
 	 "DEVICE NAME"
-	},
-	{
+ 	},
+ 	{
 	 NULL, 0,     0, NULL, 0
-	}
-    };
+ 	}
+     };
 
 gint 
 main (gint argc,gchar *argv[])
 {
     gint i;
-    gboolean is_gtk_module = FALSE;
+    gchar **argv1;
 
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, GNOPERNICUSLOCALEDIR);
@@ -275,26 +275,21 @@ main (gint argc,gchar *argv[])
 #endif
 #endif    
 
-    is_gtk_module = FALSE;
-    for (i = 0; i < argc; i++)
-	if (strncmp (argv[i], "--gtk-module", 12) == 0)
-	{
-	    is_gtk_module = TRUE;
-	    break;
-	}
-    
-    if (!is_gtk_module)
+    if (!gn_init_gconf ()) 
     {
-	gchar **argv1;
-
-	argv1 = g_new (gchar*, argc + 1);
-	for (i = 0; i < argc; i++)
-	    argv1[i] = argv[i];
-	argv1[argc] = "--gtk-module=gail:atk-bridge:gail-gnome";
-	argc++;
-	argv = argv1;
+        sru_warning (_("Gconf initialization failed."));
+	srcore_exit_all (TRUE);
+        return EXIT_FAILURE;
     }
 
+
+    argv1 = g_new (gchar*, argc + 1);
+    for (i = 0; i < argc; i++)
+	argv1[i] = argv[i];
+    argv1[argc] = "--gtk-module=gail:atk-bridge:gail-gnome";
+    argc++;
+    argv = argv1;
+
     gnome_program_init ("gnopernicus", VERSION,
 			LIBGNOMEUI_MODULE,
 			argc, argv,
@@ -304,17 +299,26 @@ main (gint argc,gchar *argv[])
 			NULL);
     sru_log_init ();
 
-/* FIXME the next line will be available only starting with gtk+ 2.6 */
-    /* gtk_window_set_default_icon_name ("gnopernicus"); */
-    gtk_window_set_default_icon_from_file (GNOPERNICUS_ICON, NULL);
-
-    if (!gn_init_gconf ()) 
+    if (srcore_magnifier_status_get ())
     {
-        sru_warning (_("Gconf initialization failed."));
-	srcore_exit_all (TRUE);
-        return EXIT_FAILURE;
+        gchar *path, *display;
+
+	path = g_strdup_printf ("%s/%s/%s", 
+			    CONFIG_PATH MAGNIFIER_PATH, 
+			    DEFAULT_MAGNIFIER_SCHEMA, 
+			     DEFAULT_MAGNIFIER_ID);
+	display = gnopiconf_get_string_from_section_with_default (path,
+				    MAGNIFIER_SOURCE, 		
+				    DEFAULT_MAGNIFIER_SOURCE);
+	gn_move_to_display (display);
+	g_free (path);
+        g_free (display);
+
     }
-                        
+
+    g_set_application_name (_("Gnopernicus"));
+    gtk_window_set_default_icon_name ("gnopernicus");
+
     if (!gn_run_with_parameters ())
     {
 	sru_warning (_("Invalid parameters."));
@@ -377,9 +381,8 @@ main (gint argc,gchar *argv[])
 
     sru_log_terminate ();
     
-    if (!is_gtk_module)
-    	g_free (argv);
-    
+    g_free (argv1);
+
     return EXIT_SUCCESS;
 }
 
