@@ -23,6 +23,7 @@
 #include "SRMessages.h"
 #include "magconf.h"
 #include "magui.h"
+#include "gnopiui.h"
 #include "gnopiconf.h"
 #include <stdlib.h>
 #include <gconf/gconf.h>
@@ -889,6 +890,12 @@ magconf_changes_cb			(GConfClient	*client,
 		    g_strdup (gconf_value_get_string (entry->value));
 		magui_set_focus_tracking (magnifier_setting);
 	    }
-	}
+	}	
 */
+	else
+	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_SOURCE) == 0)
+	{
+	    if (entry->value->type == GCONF_VALUE_STRING)
+	    	gn_move_to_display (gconf_value_get_string (entry->value));
+	}
 }
